import 'package:flutter/widgets.dart';
import '../../bolter.dart';

/// A widget for fast prototyping. otherwise use you own implementation of widget with WithPresenter mixin.
class WithPresenterBuilder<P extends Presenter<P>> extends StatelessWidget
    with WithPresenter<P> {
  final WidgetBuilder builder;
  const WithPresenterBuilder({Key? key, required this.builder})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return builder(context);
  }
}

mixin WithPresenter<P extends Presenter<P>> on Widget {
  P presenter<P extends Presenter<P>>(BuildContext context) =>
      PresenterProvider.of<P>(context);
}

extension PresenterProviderExtension on BuildContext {
  P presenter<P extends Presenter<P>>() => PresenterProvider.of<P>(this);
}
